==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PracownikParametr.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypParametruPracownika;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PracownikParametr extends GenericDPSObject {
    /**
     * PRACOWNIK_PARAMETR.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PRACOWNIK_PARAMETR.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * PRACOWNIK_PARAMETR.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypParametruPracownika typ;

    /**
     * PRACOWNIK_PARAMETR.WARTOSC_S
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String wartoscS;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRACOWNIK_PARAMETR.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PRACOWNIK_PARAMETR.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PRACOWNIK_PARAMETR.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * PRACOWNIK_PARAMETR.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PRACOWNIK_PARAMETR.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypParametruPracownika getTyp() {
        return typ;
    }

    /**
     * PRACOWNIK_PARAMETR.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypParametruPracownika typ) {
        this.typ = typ;
    }

    /**
     * @return PRACOWNIK_PARAMETR.WARTOSC_S
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * PRACOWNIK_PARAMETR.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PracownikParametr other = (PracownikParametr) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", typ=").append(typ);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PracownikParametr.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypParametruPracownika;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PracownikParametr extends GenericDPSObject {
    /**
     * PRACOWNIK_PARAMETR.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PRACOWNIK_PARAMETR.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * PRACOWNIK_PARAMETR.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypParametruPracownika typ;

    /**
     * PRACOWNIK_PARAMETR.WARTOSC_S
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String wartoscS;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PRACOWNIK_PARAMETR.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PRACOWNIK_PARAMETR.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PRACOWNIK_PARAMETR.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * PRACOWNIK_PARAMETR.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PRACOWNIK_PARAMETR.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypParametruPracownika getTyp() {
        return typ;
    }

    /**
     * PRACOWNIK_PARAMETR.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypParametruPracownika typ) {
        this.typ = typ;
    }

    /**
     * @return PRACOWNIK_PARAMETR.WARTOSC_S
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * PRACOWNIK_PARAMETR.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PracownikParametr other = (PracownikParametr) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", typ=").append(typ);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append("]");
        return sb.toString();
    }
}
